@@ -10,9 +10,9 @@ DDB_STAGE_CONTROL = os.getenv("DDB_STAGE")
 DDB_STAGE_CONTROL_LOG = os.getenv("DDB_STAGE_LOG")
 DDB_STAGE_CONTROL_FILE_BINLOG = os.getenv("DDB_STAGE_CONTROL_FILE_BINLOG")
 DDB_CUSTOMER = os.getenv("DDB_CUSTOMER")
-DDB_PARAM = os.getenv("DDB_PARAM")
+DDB_CONFIG = os.getenv("DDB_CONFIG")
 #  TODO JOB_TRANSFORMER_GLUE = os.getenv()
-LAMB_STREAMING_EXTRACTOR = os.getenv("LAMB_STREAMING_EXTRACTOR")
+LAMBDA_STREAMING_EXTRACTOR = os.getenv("LAMBDA_STREAMING_EXTRACTOR")
 DB_HOST_PATH = os.getenv("DB_HOST_PATH")
 DB_USER_PATH = os.getenv("DB_USER_PATH")
 DB_PASS_PATH = os.getenv("DB_PASS_PATH")
