@@ -1,8 +1,9 @@
 from dnxdata.utils.utils import Utils
-from dnxdata.utils.boto3 import Boto3
+from dnxdata.utils.s3 import s3
 from dnxdata.logger import Logger
 import awswrangler as wr
 import pandas as pd
+import numpy as np
 
 
 class Pandas:
@@ -10,17 +11,18 @@ class Pandas:
     def __init__(self, region=None):
         self.region = region
         self.utils = Utils()
-        self.s3 = Boto3()
+        self.s3 = s3()
         self.logger = Logger("DNX Pandas =>")
 
     # You can pass list or string path or .parquet
     def get_parquet(self, path):
-        self.logger.debug("Starting GetParquet {}".format(path))
+
+        self.logger.debug("Starting get_parquet {}".format(path))
 
         keys_s3 = self.s3.get_list_parquet(path)
         self.logger.debug("S3keys {}".format(keys_s3))
         if len(keys_s3) == 0:
-            self.logger.debug("Finishing GetParquet")
+            self.logger.debug("Finishing get_parquet")
             return pd.DataFrame()
 
         df = wr.s3.read_parquet(
@@ -29,11 +31,12 @@ class Pandas:
             validate_schema=False
         )
 
-        self.logger.debug("Finishing GetParquet")
+        self.logger.debug("Finishing get_parquet")
 
         return df
 
     def write_parquet(self, df, path, database, table, mode, partition_cols, list_path_delete):
+
         self.logger.debug("Starting Write Parquet")
 
         if (list_path_delete is not None) & (mode != "append"):
@@ -47,7 +50,9 @@ class Pandas:
             )
 
         if df.empty:
-            self.logger.debug("DF Write Parquet None or only lines with delete")
+            self.logger.debug(
+                "DF is None or DF have to only lines with delete"
+            )
         else:
             df["dt_process_parq"] = self.utils.date_time()
             df["dt_process_parq"] = pd.to_datetime(df["dt_process_parq"])
@@ -77,6 +82,7 @@ class Pandas:
         self.logger.debug("Finishing Write Parquet")
 
     def print_dtypes(self, df):
+
         self.logger.debug("Starting print_dtypes")
 
         result = {}
@@ -98,4 +104,40 @@ class Pandas:
         self.logger.debug("List index")
         self.logger.debug(index)
 
-        self.logger.debug("Finishing GetDtypesDf")
+        self.logger.debug("Finishing print_dtypes")
+
+    def convert_dtypes(self, df, list_dtypes):
+
+        self.logger.debug("Starting fix_dtypes")
+
+        columns = []
+        for col in df.dtypes.keys():
+            columns.append(col)
+
+        for column in columns:
+            dtype = list_dtypes.get(column)
+
+            if dtype is None:
+                self.logger.warning(
+                    "Column {} type {} doesn't in mapping, please verify."
+                    .format(
+                        column,
+                        dtype
+                    )
+                )
+
+            if dtype in ["int", "bigint"]:
+                df[column] = pd.to_numeric(df[column], errors='coerce')
+                df = df.replace(np.nan, 0, regex=True)
+                df[column] = df[column].astype('float').astype('int')
+            elif dtype == "datetime64":
+                df[column] = pd.to_datetime(df[column])
+            elif dtype == "str":
+                df[column] = df[column].apply(str)
+            elif dtype == "bool":
+                df[column] = df[column].astype('bool')
+
+        self.print_dtypes(df)
+        self.logger.debug("Finishing fix_dtypes")
+
+        return df
